#import "FlutterContactPlugin.h"
#import <Contacts/Contacts.h>
#import <ContactsUI/ContactsUI.h>

@interface FlutterContactPlugin ()<CNContactPickerDelegate>

@end

@implementation FlutterContactPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"flutter_contact"
            binaryMessenger:[registrar messenger]];
  FlutterContactPlugin* instance = [[FlutterContactPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } else if ([@"getContactList" isEqualToString:call.method]) {
      NSArray *dataArray = [self getContactInfoList];
      result(dataArray);
  } else {
    result(FlutterMethodNotImplemented);
  }
}

/**
 * 获取通讯录联系人信息
 * 返回信息结构数组
 */
-(NSArray *)getContactInfoList {
    NSMutableArray *dataArray = [NSMutableArray array];
    NSArray *keyToFetch = @[CNContactGivenNameKey,CNContactFamilyNameKey,CNContactPhoneNumbersKey];
    CNContactFetchRequest *request = [[CNContactFetchRequest alloc] initWithKeysToFetch:keyToFetch];
    CNContactStore *store = [[CNContactStore alloc] init];
    
    [store enumerateContactsWithFetchRequest:request error:nil usingBlock:^(CNContact * _Nonnull contact, BOOL * _Nonnull stop) {
        NSMutableDictionary *dataDict = [NSMutableDictionary dictionary];
        
        NSString * firstName = contact.familyName;
        NSString * lastName = contact.givenName;
               
        //电话
        NSArray * phoneNums = contact.phoneNumbers;
        CNLabeledValue *labelValue = phoneNums.firstObject;
        NSString *phoneValue = [labelValue.value stringValue];
        
        [dataDict setValue:firstName forKey:@"firstName"];
        [dataDict setValue:lastName forKey:@"lastName"];
        [dataDict setValue:phoneValue forKey:@"phoneValue"];
        
        [dataArray addObject:dataDict];
    }];
    return dataArray;
}

/**
 * 通讯录权限
 */

@end
